@@ -47,6 +47,9 @@ class DataFrameMmap:
             return self.get_sample(item)
         raise ValueError(f'__getitem__ argument should be either a str, or an int.')
 
+    def __len__(self):
+        return len(next(iter(self._data.values())))
+
     def append(self, dct: Dict):
         self.extend([dct])
 
